Glossary — Renku 0.10.5.dev72+dirty documentation

Join us on GitHub

# Glossary

inputs

  Files and/or directories which are required for running tools.

outputs

  Files and/or directories which are created or modified during an execution of a tool.

tool

  A description of a standalone, non-interactive program which can be invoked on some inputs, produces outputs, and then terminates 1.

1

  https://www.commonwl.org/v1.0/CommandLineTool.html